@@ -29,9 +29,10 @@ import platform
 import re
 import sys
 import warnings
+import _ped
 
-__all__ = ['alignment', 'constraint', 'device', 'disk',
-           'filesystem', 'geometry', 'partition']
+__all__ = ['Alignment', 'Constraint', 'Device', 'Disk',
+           'FileSystem', 'Geometry', 'Partition']
 
 from _ped import AlignmentException
 from _ped import CreateException
@@ -49,17 +50,17 @@ from _ped import TimerException
 from _ped import UnknownDeviceException
 from _ped import UnknownTypeException
 
-from .alignment import Alignment
-from .constraint import Constraint
-from .device import Device
-from .disk import Disk
-from .disk import diskType
-from .disk import diskFlag
-from .filesystem import FileSystem
-from .filesystem import fileSystemType
-from .geometry import Geometry
-from .partition import Partition
-from .partition import partitionFlag
+from parted.alignment import Alignment
+from parted.constraint import Constraint
+from parted.device import Device
+from parted.disk import Disk
+from parted.disk import diskType
+from parted.disk import diskFlag
+from parted.filesystem import FileSystem
+from parted.filesystem import fileSystemType
+from parted.geometry import Geometry
+from parted.partition import Partition
+from parted.partition import partitionFlag
 
 # the enumerated types in _ped need to be available from here too
 from _ped import UNIT_SECTOR
@@ -116,6 +117,15 @@ from _ped import PARTITION_APPLE_TV_RECOVERY
 from _ped import PARTITION_BIOS_GRUB
 from _ped import PARTITION_DIAG
 from _ped import PARTITION_LEGACY_BOOT
+if hasattr(_ped, 'PARTITION_MSFT_DATA'):
+    # pylint: disable=E0611
+    from _ped import PARTITION_MSFT_DATA
+if hasattr(_ped, 'PARTITION_IRST'):
+    # pylint: disable=E0611
+    from _ped import PARTITION_IRST
+if hasattr(_ped, 'PARTITION_ESP'):
+    # pylint: disable=E0611
+    from _ped import PARTITION_ESP
 
 from _ped import DISK_CYLINDER_ALIGNMENT
 from _ped import DISK_GPT_PMBR_BOOT
@@ -123,7 +133,7 @@ from _ped import DISK_GPT_PMBR_BOOT
 from _ped import DISK_TYPE_EXTENDED
 from _ped import DISK_TYPE_PARTITION_NAME
 
-from .decorators import localeC
+from parted.decorators import localeC
 
 if sys.version_info >= (3,):
     string_types = str
@@ -281,7 +291,11 @@ archLabels = {'i386': ['msdos', 'gpt'],
               'sparc': ['sun'],
               'ia64': ['msdos', 'gpt'],
               'ppc': ['msdos', 'mac', 'amiga', 'gpt'],
-              'x86_64': ['msdos', 'gpt']}
+              'ppc64': ['msdos', 'mac', 'amiga', 'gpt'],
+              'ppc64le': ['msdos', 'gpt'],
+              'x86_64': ['msdos', 'gpt'],
+              'aarch64': ['msdos', 'gpt'],
+              'armv7l': ['msdos', 'gpt']}
 
 # Adapted from:
 # http://stackoverflow.com/questions/922550/how-to-mark-a-global-as-deprecated-in-python
@@ -289,9 +303,12 @@ archLabels = {'i386': ['msdos', 'gpt'],
 # Remember that DeprecationWarnings are ignored by default as they are not really
 # useful to users.  Developers can turn on DeprecationWarning notices by passing
 # the -Wd option to python or by setting PYTHONWARNINGS=d in the environment.
-def Deprecated(mod, deprecated={}):
+def Deprecated(mod, deprecated=None):
     """ Return a wrapped object that warns about deprecated accesses. """
 
+    if not deprecated:
+        deprecated = {}
+
     class Wrapper(object):
         warnmsg = "%s is deprecated and will be removed in a future release."
 
@@ -306,7 +323,7 @@ def Deprecated(mod, deprecated={}):
             if attr in deprecated.keys():
                 msg = self.warnmsg + " " + deprecated[attr]
                 warnings.warn(msg % attr, DeprecationWarning)
-            return setattr(mod, attr, value)
+            setattr(mod, attr, value)
 
     return Wrapper()
 
@@ -315,9 +332,9 @@ def Deprecated(mod, deprecated={}):
 __archLabels = (('amiga', 'ppc(64)?$'),
                 ('bsd', 'alpha$'),
                 ('dasd', 's390x?$'),
-                ('gpt', 'i[3-6]86$|x86_64$|ia64$|ppc(64)?$'),
+                ('gpt', 'i[3-6]86$|x86_64$|ia64$|ppc(64|64le)?$|aarch64$|armv7l$'),
                 ('mac', 'ppc(64)?$'),
-                ('msdos', 'i[3-6]86$|x86_64$|s390x?$|alpha$|ia64$|ppc(64)?$'),
+                ('msdos', 'i[3-6]86$|x86_64$|s390x?$|alpha$|ia64$|ppc(64|64le)?$|aarch64$|armv7l$'),
                 ('sun', 'sparc(64)?$'))
 
 def getLabels(arch=None):
@@ -337,14 +354,16 @@ def getLabels(arch=None):
 class ReadOnlyProperty(Exception):
     """Exception raised when a write operation occurs on a read-only property."""
 
-    def __init__(self, property=''):
-        self.message = "%s is a read-only property" % (property,)
+    # pylint: disable=W0231
+    def __init__(self, prop=''):
+        self.message = "%s is a read-only property" % (prop,)
 
 class WriteOnlyProperty(Exception):
     """Exception raised when a read operation occurs on a write-only property."""
 
-    def __init__(self, property=''):
-        self.message = "%s is a write-only property" % (property,)
+    # pylint: disable=W0231
+    def __init__(self, prop=''):
+        self.message = "%s is a write-only property" % (prop,)
 
 @localeC
 def getDevice(path):
