@@ -25,8 +25,8 @@
 import _ped
 import parted
 
-from .cachedlist import CachedList
-from .decorators import localeC
+from cachedlist import CachedList
+from decorators import localeC
 
 class Disk(object):
     """Disk()
@@ -52,6 +52,7 @@ class Disk(object):
             self.__disk = _ped.Disk(device.getPedDevice())
             self._device = device
 
+        # pylint: disable=W0108
         self._partitions = CachedList(lambda : self.__getPartitions())
 
     def _hasSameParts(self, other):
@@ -453,7 +454,7 @@ class Disk(object):
         """Return a Partition object associated with the partition device
            path, such as /dev/sda1.  Returns None if no partition is found."""
         for partition in self.partitions:
-            if "/dev/%s" % partition.getDeviceNodeName() == path:
+            if partition.path == path:
                 return partition
 
         return None
