@@ -26,10 +26,10 @@
 import math
 import warnings
 
-import _ped
 import parted
+import _ped
 
-from .decorators import localeC
+from parted.decorators import localeC
 
 class Geometry(object):
     """Geometry()
