@@ -2,7 +2,7 @@
 # Test cases for the methods in the _ped module itself - just the pyunit
 # and pynatmath files.
 #
-# Copyright (C) 2008-2011  Red Hat, Inc.
+# Copyright (C) 2008-2014  Red Hat, Inc.
 #
 # This copyrighted material is made available to anyone wishing to use,
 # modify, copy, or redistribute it subject to the terms and conditions of
@@ -34,14 +34,19 @@ from tests.baseclass import *
 # multiple classes and their own test suite.
 class PartitionFlagGetNameTestCase(unittest.TestCase):
     def runTest(self):
-        for f in [_ped.PARTITION_BOOT, _ped.PARTITION_ROOT, _ped.PARTITION_SWAP,
-                  _ped.PARTITION_HIDDEN, _ped.PARTITION_RAID, _ped.PARTITION_LVM,
-                  _ped.PARTITION_LBA, _ped.PARTITION_HPSERVICE,
-                  _ped.PARTITION_PALO, _ped.PARTITION_PREP,
-                  _ped.PARTITION_MSFT_RESERVED,
-                  _ped.PARTITION_APPLE_TV_RECOVERY,
-                  _ped.PARTITION_BIOS_GRUB, _ped.PARTITION_DIAG]:
-            self.assertNotEqual(_ped.partition_flag_get_name(f), "", "Could not get name for flag %s" % f)
+        for f in ['PARTITION_BOOT', 'PARTITION_ROOT', 'PARTITION_SWAP',
+                  'PARTITION_HIDDEN', 'PARTITION_RAID', 'PARTITION_LVM',
+                  'PARTITION_LBA', 'PARTITION_HPSERVICE',
+                  'PARTITION_PALO', 'PARTITION_PREP',
+                  'PARTITION_MSFT_RESERVED',
+                  'PARTITION_APPLE_TV_RECOVERY',
+                  'PARTITION_BIOS_GRUB', 'PARTITION_DIAG',
+                  'PARTITION_MSFT_DATA', 'PARTITION_IRST',
+                  'PARTITION_ESP']:
+            if not hasattr(_ped, f):
+                continue
+            attr = getattr(_ped, f)
+            self.assertNotEqual(_ped.partition_flag_get_name(attr), "", "Could not get name for flag _ped.%s" % f)
 
         self.assertRaises(ValueError, _ped.partition_flag_get_name, -1)
         self.assertRaises(ValueError, _ped.partition_flag_get_name, 1000)
@@ -49,7 +54,8 @@ class PartitionFlagGetNameTestCase(unittest.TestCase):
 class PartitionFlagGetByNameTestCase(unittest.TestCase):
     def runTest(self):
         for f in ["boot", "root", "swap", "hidden", "raid", "lvm", "lba",
-                  "hp-service", "palo", "prep", "msftres", "bios_grub"]:
+                  "hp-service", "palo", "prep", "msftres", "bios_grub",
+                  "msftdata", "irst", "esp"]:
             self.assertNotEqual(_ped.partition_flag_get_by_name(f), "", "Could not get flag %s" % f)
 
         self.assertEqual(_ped.partition_flag_get_by_name("nosuchflag"), 0)
@@ -274,8 +280,8 @@ class FileSystemProbeSpecificTestCase(RequiresFileSystem):
 
                 self.assertIsInstance(result, _ped.Geometry)
                 self.assertEqual(result.start, self._geometry.start)
-                self.assertEqual(result.end, self._geometry.end)
-                self.assertEqual(result.length, self._geometry.length)
+                self.assertLessEqual(result.end, self._geometry.end)
+                self.assertLessEqual(result.length, self._geometry.length)
                 self.assertEqual(result.dev, self._device)
             else:
                 result = _ped.file_system_probe_specific(type, self._geometry)
@@ -283,11 +289,16 @@ class FileSystemProbeSpecificTestCase(RequiresFileSystem):
 
 class FileSystemTypeGetTestCase(unittest.TestCase):
     def runTest(self):
-        for f in ["affs0", "amufs", "apfs1", "asfs", "ext2", "ext3", "fat16",
+        for f in ["affs0", "amufs", "apfs1", "asfs", "btrfs", "ext2", "ext3", "ext4", "fat16",
                   "fat32", "hfs", "hfs+", "hfsx", "hp-ufs", "jfs", "linux-swap",
                   "ntfs", "reiserfs", "sun-ufs", "xfs"]:
-            self.assertIsInstance(_ped.file_system_type_get(f), _ped.FileSystemType,
-                         "Could not get fs type %s" % f)
+            # may be missing some filesystem types depending on the parted
+            # build on the test system
+            try:
+                t = _ped.file_system_type_get(f)
+                self.assertIsInstance(_ped.file_system_type_get(f), _ped.FileSystemType, "Could not get fs type %s" % f)
+            except _ped.UnknownTypeException:
+                pass
 
         self.assertRaises(_ped.UnknownTypeException, _ped.file_system_type_get, "nosuch")
 
